@@ -19,7 +19,7 @@ import ruamel.yaml
 logger = logging.getLogger(__name__)
 
 
-def _get_connection_options(data: Dict[str, Any]) -> ConnectionOptions:
+def _get_connection_options(data: Dict[str, Any]) -> Dict[str, ConnectionOptions]:
     cp = {}
     for cn, c in data.items():
         cp[cn] = ConnectionOptions(
@@ -113,10 +113,10 @@ class YAMLInventory:
             for n, g in groups_dict.items():
                 groups[n] = _get_inventory_element(Group, g, n, defaults)
 
-            for h in hosts.values():
-                h.groups = ParentGroups([groups[g] for g in h.groups])
-
             for g in groups.values():
                 g.groups = ParentGroups([groups[g] for g in g.groups])
 
+        for h in hosts.values():
+            h.groups = ParentGroups([groups[g] for g in h.groups])
+
         return Inventory(hosts=hosts, groups=groups, defaults=defaults)
